@@ -628,7 +628,12 @@ Theta.EAP <- function(IP, SE = TRUE, precision = 4, N.nodes = 30)
     Th.condensed <- res
     Th.full      <- res[ind]
     Th.full.all  <- rep(NA, N)
-    Th.full.all[-rows.rm] <- Th.full
+    
+    if (length(rows.rm) > 0) {
+      Th.full.all[-rows.rm] <- Th.full
+    } else {
+      Th.full.all <- Th.full
+    }
     
     if (SE)
     {
@@ -639,7 +644,12 @@ Theta.EAP <- function(IP, SE = TRUE, precision = 4, N.nodes = 30)
       Th.SE.full  <- sqrt(num.SE / den)[ind]
       # 
       Th.SE.full.all           <- rep(NA, N)
-      Th.SE.full.all[-rows.rm] <- Th.SE.full
+      
+      if (length(rows.rm) > 0) {
+        Th.SE.full.all[-rows.rm] <- Th.SE.full
+      } else {
+        Th.SE.full.all <- Th.SE.full
+      }
       
       return(cbind(
         Person   = (1:N), 
